@@ -1160,7 +1160,7 @@ my %sSubVersion = (
     ReleaseTime         => { Avoid => 1 },
     OriginatingProgram  => { Avoid => 1 },
     ObjectCycle         => { Avoid => 1 },
-    Snapshots           => { Avoid => 1, List => 'Bag' },
+    Snapshots           => { Avoid => 1, List => 'Bag', Binary => 1 },
 );
 
 # Picture Licensing Universal System namespace properties (xmpPLUS)
